variable "vpc_id" {
  description = "ID of the VPC where the EKS cluster will be created (from VPC module)"
  type        = string
}

variable "private_subnet_ids" {
  description = "List of private subnet IDs for worker nodes and cluster ENIs (from VPC module)"
  type        = list(string)
}

variable "cluster_version" {
  description = "Kubernetes version for the EKS cluster"
  type        = string
  default     = {{ eks.cluster_version | terraform_quote }}
}

variable "node_instance_type" {
  description = "EC2 instance type for worker nodes"
  type        = string
  default     = {{ eks.node_instance_type | terraform_quote }}
}

variable "node_desired_capacity" {
  description = "Desired number of worker nodes in the node group"
  type        = number
  default     = {{ eks.node_desired_size }}
}

variable "node_min_size" {
  description = "Minimum number of worker nodes in the node group"
  type        = number
  default     = {{ eks.node_min_size }}
}

variable "node_max_size" {
  description = "Maximum number of worker nodes in the node group"
  type        = number
  default     = {{ eks.node_max_size }}
}

variable "environment" {
  description = "Logical environment for this EKS cluster (e.g., dev, staging, production)"
  type        = string
  default     = {{ environment | terraform_quote }}
}
