# Root variables for iacgen-generated infrastructure

variable "project_name" {
  description = "Name of the project/infrastructure"
  type        = string
  default     = {{ name | terraform_quote }}
}

variable "region" {
  description = "AWS region for all resources"
  type        = string
  default     = {{ region | terraform_quote }}
}

variable "environment" {
  description = "Logical environment (e.g., dev, staging, prod)"
  type        = string
  default     = {{ environment | terraform_quote }}
}
