variable "vpc_id" {
  description = "ID of the VPC where the ALB will be created"
  type        = string
}

variable "subnet_ids" {
  description = "List of subnet IDs where the ALB will be placed (typically public subnets)"
  type        = list(string)
}

variable "certificate_arn" {
  description = "ARN of the ACM certificate to use for HTTPS listeners"
  type        = string
  default     = ""
}

variable "health_check_path" {
  description = "HTTP path used for target group health checks"
  type        = string
  default     = {{ "/health" | terraform_quote }}
}

variable "enable_deletion_protection" {
  description = "Enable deletion protection on the ALB"
  type        = bool
  default     = false
}

variable "ssl_policy" {
  description = "SSL policy to use for HTTPS listeners (defaults to AWS recommended policy)"
  type        = string
  default     = "ELBSecurityPolicy-2016-08"
}

variable "environment" {
  description = "Logical environment for this ALB (e.g., dev, staging, production)"
  type        = string
  default     = {{ environment | terraform_quote }}
}
