# Root outputs for iacgen-generated infrastructure

output "project_name" {
  description = "Name of the project/infrastructure"
  value       = "{{ name }}"
}

output "region" {
  description = "AWS region used for this deployment"
  value       = "{{ region }}"
}

output "environment" {
  description = "Logical environment for this deployment"
  value       = "{{ environment }}"
}
