# Example variable values for the generated infrastructure
# Users can override these as needed.

project_name = {{ name | terraform_quote }}
region       = {{ region | terraform_quote }}
environment  = {{ environment | terraform_quote }}
