variable "cidr_block" {
  description = "CIDR block for the VPC"
  type        = string
  default     = {{ vpc.cidr_block | terraform_quote }}
}

variable "availability_zones" {
  description = "Number of availability zones to use"
  type        = number
  default     = {{ vpc.availability_zones }}
}

variable "environment" {
  description = "Logical environment for this VPC (e.g., dev, staging, production)"
  type        = string
  # Default comes from the blueprint configuration but can be
  # overridden via terraform.tfvars or -var on the CLI.
  default     = {{ environment | terraform_quote }}
}
